@@ -22,7 +22,7 @@
 #include "process.h"
 #include "vt.h"
 
-struct XServerLocalPrivate
+typedef struct
 {
     /* X server process */
     Process *x_server_process;
@@ -66,11 +66,12 @@ struct XServerLocalPrivate
 
     /* Background to set */
     gchar *background;
-};
+} XServerLocalPrivate;
 
 static void x_server_local_logger_iface_init (LoggerInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (XServerLocal, x_server_local, X_SERVER_TYPE,
+                         G_ADD_PRIVATE (XServerLocal)
                          G_IMPLEMENT_INTERFACE (LOGGER_TYPE, x_server_local_logger_iface_init))
 
 static gchar *version = NULL;
@@ -187,120 +188,137 @@ x_server_local_new (void)
 void
 x_server_local_set_command (XServerLocal *server, const gchar *command)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    g_free (server->priv->command);
-    server->priv->command = g_strdup (command);
+    g_free (priv->command);
+    priv->command = g_strdup (command);
 }
 
 void
 x_server_local_set_vt (XServerLocal *server, gint vt)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
+
     g_return_if_fail (server != NULL);
-    if (server->priv->have_vt_ref)
-        vt_unref (server->priv->vt);
-    server->priv->have_vt_ref = FALSE;
-    server->priv->vt = vt;
+
+    if (priv->have_vt_ref)
+        vt_unref (priv->vt);
+    priv->have_vt_ref = FALSE;
+    priv->vt = vt;
     if (vt > 0)
     {
         vt_ref (vt);
-        server->priv->have_vt_ref = TRUE;
+        priv->have_vt_ref = TRUE;
     }
 }
 
 void
 x_server_local_set_config (XServerLocal *server, const gchar *path)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    g_free (server->priv->config_file);
-    server->priv->config_file = g_strdup (path);
+    g_free (priv->config_file);
+    priv->config_file = g_strdup (path);
 }
 
 void
 x_server_local_set_layout (XServerLocal *server, const gchar *layout)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    g_free (server->priv->layout);
-    server->priv->layout = g_strdup (layout);
+    g_free (priv->layout);
+    priv->layout = g_strdup (layout);
 }
 
 void
 x_server_local_set_xdg_seat (XServerLocal *server, const gchar *xdg_seat)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    g_free (server->priv->xdg_seat);
-    server->priv->xdg_seat = g_strdup (xdg_seat);
+    g_free (priv->xdg_seat);
+    priv->xdg_seat = g_strdup (xdg_seat);
 }
 
 void
 x_server_local_set_allow_tcp (XServerLocal *server, gboolean allow_tcp)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    server->priv->allow_tcp = allow_tcp;
+    priv->allow_tcp = allow_tcp;
 }
 
 void
 x_server_local_set_xdmcp_server (XServerLocal *server, const gchar *hostname)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    g_free (server->priv->xdmcp_server);
-    server->priv->xdmcp_server = g_strdup (hostname);
+    g_free (priv->xdmcp_server);
+    priv->xdmcp_server = g_strdup (hostname);
 }
 
 const gchar *
 x_server_local_get_xdmcp_server (XServerLocal *server)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_val_if_fail (server != NULL, 0);
-    return server->priv->xdmcp_server;
+    return priv->xdmcp_server;
 }
 
 void
 x_server_local_set_xdmcp_port (XServerLocal *server, guint port)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    server->priv->xdmcp_port = port;
+    priv->xdmcp_port = port;
 }
 
 guint
 x_server_local_get_xdmcp_port (XServerLocal *server)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_val_if_fail (server != NULL, 0);
-    return server->priv->xdmcp_port;
+    return priv->xdmcp_port;
 }
 
 void
 x_server_local_set_xdmcp_key (XServerLocal *server, const gchar *key)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    g_free (server->priv->xdmcp_key);
-    server->priv->xdmcp_key = g_strdup (key);
+    g_free (priv->xdmcp_key);
+    priv->xdmcp_key = g_strdup (key);
     x_server_set_authority (X_SERVER (server), NULL);
 }
 
 void
 x_server_local_set_background (XServerLocal *server, const gchar *background)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_if_fail (server != NULL);
-    g_free (server->priv->background);
-    server->priv->background = g_strdup (background);
+    g_free (priv->background);
+    priv->background = g_strdup (background);
 }
 
 static guint
 x_server_local_get_display_number (XServer *server)
 {
-    return X_SERVER_LOCAL (server)->priv->display_number;
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (X_SERVER_LOCAL (server));
+    return priv->display_number;
 }
 
 static gint
 x_server_local_get_vt (DisplayServer *server)
 {
-    return X_SERVER_LOCAL (server)->priv->vt;
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (X_SERVER_LOCAL (server));
+    return priv->vt;
 }
 
 const gchar *
 x_server_local_get_authority_file_path (XServerLocal *server)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
     g_return_val_if_fail (server != NULL, 0);
-    return server->priv->authority_file;
+    return priv->authority_file;
 }
 
 static gchar *
@@ -347,10 +365,12 @@ x_server_local_get_log_stdout (XServerLocal *server)
 static void
 got_signal_cb (Process *process, int signum, XServerLocal *server)
 {
-    if (signum == SIGUSR1 && !server->priv->got_signal)
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
+
+    if (signum == SIGUSR1 && !priv->got_signal)
     {
-        server->priv->got_signal = TRUE;
-        l_debug (server, "Got signal from X server :%d", server->priv->display_number);
+        priv->got_signal = TRUE;
+        l_debug (server, "Got signal from X server :%d", priv->display_number);
 
         // FIXME: Check return value
         DISPLAY_SERVER_CLASS (x_server_local_parent_class)->start (DISPLAY_SERVER (server));
@@ -360,24 +380,26 @@ got_signal_cb (Process *process, int signum, XServerLocal *server)
 static void
 stopped_cb (Process *process, XServerLocal *server)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
+
     l_debug (server, "X server stopped");
 
     /* Release VT and display number for re-use */
-    if (server->priv->have_vt_ref)
+    if (priv->have_vt_ref)
     {
-        vt_unref (server->priv->vt);
-        server->priv->have_vt_ref = FALSE;
+        vt_unref (priv->vt);
+        priv->have_vt_ref = FALSE;
     }
-    x_server_local_release_display_number (server->priv->display_number);
+    x_server_local_release_display_number (priv->display_number);
 
-    if (x_server_get_authority (X_SERVER (server)) && server->priv->authority_file)
+    if (x_server_get_authority (X_SERVER (server)) && priv->authority_file)
     {
-        l_debug (server, "Removing X server authority %s", server->priv->authority_file);
+        l_debug (server, "Removing X server authority %s", priv->authority_file);
 
-        g_unlink (server->priv->authority_file);
+        g_unlink (priv->authority_file);
 
-        g_free (server->priv->authority_file);
-        server->priv->authority_file = NULL;
+        g_free (priv->authority_file);
+        priv->authority_file = NULL;
     }
 
     DISPLAY_SERVER_CLASS (x_server_local_parent_class)->stop (DISPLAY_SERVER (server));
@@ -386,12 +408,14 @@ stopped_cb (Process *process, XServerLocal *server)
 static void
 write_authority_file (XServerLocal *server)
 {
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
+
     XAuthority *authority = x_server_get_authority (X_SERVER (server));
     if (!authority)
         return;
 
     /* Get file to write to if have authority */
-    if (!server->priv->authority_file)
+    if (!priv->authority_file)
     {
         g_autofree gchar *run_dir = NULL;
         g_autofree gchar *dir = NULL;
@@ -401,13 +425,13 @@ write_authority_file (XServerLocal *server)
         if (g_mkdir_with_parents (dir, S_IRWXU) < 0)
             l_warning (server, "Failed to make authority directory %s: %s", dir, strerror (errno));
 
-        server->priv->authority_file = g_build_filename (dir, x_server_get_address (X_SERVER (server)), NULL);
+        priv->authority_file = g_build_filename (dir, x_server_get_address (X_SERVER (server)), NULL);
     }
 
-    l_debug (server, "Writing X server authority to %s", server->priv->authority_file);
+    l_debug (server, "Writing X server authority to %s", priv->authority_file);
 
     g_autoptr(GError) error = NULL;
-    x_authority_write (authority, XAUTH_WRITE_MODE_REPLACE, server->priv->authority_file, &error);
+    x_authority_write (authority, XAUTH_WRITE_MODE_REPLACE, priv->authority_file, &error);
     if (error)
         l_warning (server, "Failed to write authority: %s", error->message);
 }
@@ -416,61 +440,62 @@ static gboolean
 x_server_local_start (DisplayServer *display_server)
 {
     XServerLocal *server = X_SERVER_LOCAL (display_server);
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
 
-    g_return_val_if_fail (server->priv->x_server_process == NULL, FALSE);
+    g_return_val_if_fail (priv->x_server_process == NULL, FALSE);
 
-    server->priv->got_signal = FALSE;
+    priv->got_signal = FALSE;
 
-    g_return_val_if_fail (server->priv->command != NULL, FALSE);
+    g_return_val_if_fail (priv->command != NULL, FALSE);
 
     ProcessRunFunc run_cb = X_SERVER_LOCAL_GET_CLASS (server)->get_run_function (server);
-    server->priv->x_server_process = process_new (run_cb, server);
-    process_set_clear_environment (server->priv->x_server_process, TRUE);
-    g_signal_connect (server->priv->x_server_process, PROCESS_SIGNAL_GOT_SIGNAL, G_CALLBACK (got_signal_cb), server);
-    g_signal_connect (server->priv->x_server_process, PROCESS_SIGNAL_STOPPED, G_CALLBACK (stopped_cb), server);
+    priv->x_server_process = process_new (run_cb, server);
+    process_set_clear_environment (priv->x_server_process, TRUE);
+    g_signal_connect (priv->x_server_process, PROCESS_SIGNAL_GOT_SIGNAL, G_CALLBACK (got_signal_cb), server);
+    g_signal_connect (priv->x_server_process, PROCESS_SIGNAL_STOPPED, G_CALLBACK (stopped_cb), server);
 
     /* Setup logging */
     g_autofree gchar *filename = g_strdup_printf ("x-%d.log", x_server_get_display_number (X_SERVER (server)));
     g_autofree gchar *dir = config_get_string (config_get_instance (), "LightDM", "log-directory");
     g_autofree gchar *log_file = g_build_filename (dir, filename, NULL);
     gboolean backup_logs = config_get_boolean (config_get_instance (), "LightDM", "backup-logs");
-    process_set_log_file (server->priv->x_server_process, log_file, X_SERVER_LOCAL_GET_CLASS (server)->get_log_stdout (server), backup_logs ? LOG_MODE_BACKUP_AND_TRUNCATE : LOG_MODE_APPEND);
+    process_set_log_file (priv->x_server_process, log_file, X_SERVER_LOCAL_GET_CLASS (server)->get_log_stdout (server), backup_logs ? LOG_MODE_BACKUP_AND_TRUNCATE : LOG_MODE_APPEND);
     l_debug (display_server, "Logging to %s", log_file);
 
-    g_autofree gchar *absolute_command = get_absolute_command (server->priv->command);
+    g_autofree gchar *absolute_command = get_absolute_command (priv->command);
     if (!absolute_command)
     {
-        l_debug (display_server, "Can't launch X server %s, not found in path", server->priv->command);
-        stopped_cb (server->priv->x_server_process, X_SERVER_LOCAL (server));
+        l_debug (display_server, "Can't launch X server %s, not found in path", priv->command);
+        stopped_cb (priv->x_server_process, X_SERVER_LOCAL (server));
         return FALSE;
     }
     g_autoptr(GString) command = g_string_new (absolute_command);
 
-    g_string_append_printf (command, " :%d", server->priv->display_number);
+    g_string_append_printf (command, " :%d", priv->display_number);
 
-    if (server->priv->config_file)
-        g_string_append_printf (command, " -config %s", server->priv->config_file);
+    if (priv->config_file)
+        g_string_append_printf (command, " -config %s", priv->config_file);
 
-    if (server->priv->layout)
-        g_string_append_printf (command, " -layout %s", server->priv->layout);
+    if (priv->layout)
+        g_string_append_printf (command, " -layout %s", priv->layout);
 
-    if (server->priv->xdg_seat)
-        g_string_append_printf (command, " -seat %s", server->priv->xdg_seat);
+    if (priv->xdg_seat)
+        g_string_append_printf (command, " -seat %s", priv->xdg_seat);
 
     write_authority_file (server);
-    if (server->priv->authority_file)
-        g_string_append_printf (command, " -auth %s", server->priv->authority_file);
+    if (priv->authority_file)
+        g_string_append_printf (command, " -auth %s", priv->authority_file);
 
     /* Connect to a remote server using XDMCP */
-    if (server->priv->xdmcp_server != NULL)
+    if (priv->xdmcp_server != NULL)
     {
-        if (server->priv->xdmcp_port != 0)
-            g_string_append_printf (command, " -port %d", server->priv->xdmcp_port);
-        g_string_append_printf (command, " -query %s", server->priv->xdmcp_server);
-        if (server->priv->xdmcp_key)
-            g_string_append_printf (command, " -cookie %s", server->priv->xdmcp_key);
+        if (priv->xdmcp_port != 0)
+            g_string_append_printf (command, " -port %d", priv->xdmcp_port);
+        g_string_append_printf (command, " -query %s", priv->xdmcp_server);
+        if (priv->xdmcp_key)
+            g_string_append_printf (command, " -cookie %s", priv->xdmcp_key);
     }
-    else if (server->priv->allow_tcp)
+    else if (priv->allow_tcp)
     {
         if (x_server_local_version_compare (1, 17) >= 0)
             g_string_append (command, " -listen tcp");
@@ -478,50 +503,50 @@ x_server_local_start (DisplayServer *display_server)
     else
         g_string_append (command, " -nolisten tcp");
 
-    if (server->priv->vt >= 0)
-        g_string_append_printf (command, " vt%d -novtswitch", server->priv->vt);
+    if (priv->vt >= 0)
+        g_string_append_printf (command, " vt%d -novtswitch", priv->vt);
 
-    if (server->priv->background)
-        g_string_append_printf (command, " -background %s", server->priv->background);
+    if (priv->background)
+        g_string_append_printf (command, " -background %s", priv->background);
 
     /* Allow sub-classes to add arguments */
     if (X_SERVER_LOCAL_GET_CLASS (server)->add_args)
         X_SERVER_LOCAL_GET_CLASS (server)->add_args (server, command);
 
-    process_set_command (server->priv->x_server_process, command->str);
+    process_set_command (priv->x_server_process, command->str);
 
     l_debug (display_server, "Launching X Server");
 
     /* If running inside another display then pass through those variables */
     if (g_getenv ("DISPLAY"))
     {
-        process_set_env (server->priv->x_server_process, "DISPLAY", g_getenv ("DISPLAY"));
+        process_set_env (priv->x_server_process, "DISPLAY", g_getenv ("DISPLAY"));
         if (g_getenv ("XAUTHORITY"))
-            process_set_env (server->priv->x_server_process, "XAUTHORITY", g_getenv ("XAUTHORITY"));
+            process_set_env (priv->x_server_process, "XAUTHORITY", g_getenv ("XAUTHORITY"));
         else
         {
             g_autofree gchar *path = g_build_filename (g_get_home_dir (), ".Xauthority", NULL);
-            process_set_env (server->priv->x_server_process, "XAUTHORITY", path);
+            process_set_env (priv->x_server_process, "XAUTHORITY", path);
         }
     }
 
     /* Pass through library variables */
     if (g_getenv ("LD_PRELOAD"))
-        process_set_env (server->priv->x_server_process, "LD_PRELOAD", g_getenv ("LD_PRELOAD"));
+        process_set_env (priv->x_server_process, "LD_PRELOAD", g_getenv ("LD_PRELOAD"));
     if (g_getenv ("LD_LIBRARY_PATH"))
-        process_set_env (server->priv->x_server_process, "LD_LIBRARY_PATH", g_getenv ("LD_LIBRARY_PATH"));
+        process_set_env (priv->x_server_process, "LD_LIBRARY_PATH", g_getenv ("LD_LIBRARY_PATH"));
     if (g_getenv ("PATH"))
-        process_set_env (server->priv->x_server_process, "PATH", g_getenv ("PATH"));
+        process_set_env (priv->x_server_process, "PATH", g_getenv ("PATH"));
 
     /* Variable required for regression tests */
     if (g_getenv ("LIGHTDM_TEST_ROOT"))
-        process_set_env (server->priv->x_server_process, "LIGHTDM_TEST_ROOT", g_getenv ("LIGHTDM_TEST_ROOT"));
+        process_set_env (priv->x_server_process, "LIGHTDM_TEST_ROOT", g_getenv ("LIGHTDM_TEST_ROOT"));
 
-    gboolean result = process_start (server->priv->x_server_process, FALSE);
+    gboolean result = process_start (priv->x_server_process, FALSE);
     if (result)
-        l_debug (display_server, "Waiting for ready signal from X server :%d", server->priv->display_number);
+        l_debug (display_server, "Waiting for ready signal from X server :%d", priv->display_number);
     else
-        stopped_cb (server->priv->x_server_process, X_SERVER_LOCAL (server));
+        stopped_cb (priv->x_server_process, X_SERVER_LOCAL (server));
 
     return result;
 }
@@ -529,36 +554,38 @@ x_server_local_start (DisplayServer *display_server)
 static void
 x_server_local_stop (DisplayServer *server)
 {
-    process_stop (X_SERVER_LOCAL (server)->priv->x_server_process);
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (X_SERVER_LOCAL (server));
+    process_stop (priv->x_server_process);
 }
 
 static void
 x_server_local_init (XServerLocal *server)
 {
-    server->priv = G_TYPE_INSTANCE_GET_PRIVATE (server, X_SERVER_LOCAL_TYPE, XServerLocalPrivate);
-    server->priv->vt = -1;
-    server->priv->command = g_strdup ("X");
-    server->priv->display_number = x_server_local_get_unused_display_number ();
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
+    priv->vt = -1;
+    priv->command = g_strdup ("X");
+    priv->display_number = x_server_local_get_unused_display_number ();
 }
 
 static void
 x_server_local_finalize (GObject *object)
 {
     XServerLocal *self = X_SERVER_LOCAL (object);
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (self);
 
-    if (self->priv->x_server_process)
-        g_signal_handlers_disconnect_matched (self->priv->x_server_process, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, self);
-    g_clear_object (&self->priv->x_server_process);
-    g_clear_pointer (&self->priv->command, g_free);
-    g_clear_pointer (&self->priv->config_file, g_free);
-    g_clear_pointer (&self->priv->layout, g_free);
-    g_clear_pointer (&self->priv->xdg_seat, g_free);
-    g_clear_pointer (&self->priv->xdmcp_server, g_free);
-    g_clear_pointer (&self->priv->xdmcp_key, g_free);
-    g_clear_pointer (&self->priv->authority_file, g_free);
-    if (self->priv->have_vt_ref)
-        vt_unref (self->priv->vt);
-    g_clear_pointer (&self->priv->background, g_free);
+    if (priv->x_server_process)
+        g_signal_handlers_disconnect_matched (priv->x_server_process, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, self);
+    g_clear_object (&priv->x_server_process);
+    g_clear_pointer (&priv->command, g_free);
+    g_clear_pointer (&priv->config_file, g_free);
+    g_clear_pointer (&priv->layout, g_free);
+    g_clear_pointer (&priv->xdg_seat, g_free);
+    g_clear_pointer (&priv->xdmcp_server, g_free);
+    g_clear_pointer (&priv->xdmcp_key, g_free);
+    g_clear_pointer (&priv->authority_file, g_free);
+    if (priv->have_vt_ref)
+        vt_unref (priv->vt);
+    g_clear_pointer (&priv->background, g_free);
 
     G_OBJECT_CLASS (x_server_local_parent_class)->finalize (object);
 }
@@ -577,15 +604,14 @@ x_server_local_class_init (XServerLocalClass *klass)
     display_server_class->start = klass->start = x_server_local_start;
     display_server_class->stop = x_server_local_stop;
     object_class->finalize = x_server_local_finalize;
-
-    g_type_class_add_private (klass, sizeof (XServerLocalPrivate));
 }
 
 static gint
 x_server_local_real_logprefix (Logger *self, gchar *buf, gulong buflen)
 {
     XServerLocal *server = X_SERVER_LOCAL (self);
-    return g_snprintf (buf, buflen, "XServer %d: ", server->priv->display_number);
+    XServerLocalPrivate *priv = x_server_local_get_instance_private (server);
+    return g_snprintf (buf, buflen, "XServer %d: ", priv->display_number);
 }
 
 static void
